Learn R Programming

carts (version 0.1.0)

outcome_phreg: Outcome model for time-to-event end-points (proportional hazards)

Description

Outcome model for time-to-event end-points (proportional hazards)

Usage

outcome_phreg(
  data,
  lp = NULL,
  par = NULL,
  outcome.name = c("time", "status"),
  remove = c("id", "num"),
  model = NULL,
  cens.model = NULL,
  cens.lp = NULL,
  cens.par = NULL,
  ...
)

Value

data.table

Arguments

data

(data.table) Covariate data, usually the output of the covariate model of a Trial object.

lp

linear predictor (formula or function)

par

optional list of model parameter

outcome.name

names of outcome (time and censoring status)

remove

Variables that will be removed from input data (if formula is not specified).

model

optional mets::phreg object

cens.model

optional model for censoring mechanism

cens.lp

censoring linear predictor argument (formula or function)

cens.par

list of censoring model parameters

...

Additional arguments to outcome_lp

Author

Klaus Kähler Holst