Outcome model for time-to-event end-points (proportional hazards)
outcome_phreg(
data,
lp = NULL,
par = NULL,
outcome.name = c("time", "status"),
remove = c("id", "num"),
model = NULL,
cens.model = NULL,
cens.lp = NULL,
cens.par = NULL,
...
)data.table
(data.table) Covariate data, usually the output of the covariate model of a Trial object.
linear predictor (formula or function)
optional list of model parameter
names of outcome (time and censoring status)
Variables that will be removed from input data (if formula is
not specified).
optional mets::phreg object
optional model for censoring mechanism
censoring linear predictor argument (formula or function)
list of censoring model parameters
Additional arguments to outcome_lp
Klaus Kähler Holst