This function is still in an experimental state where the interface and functionality might change in the future
outcome_recurrent(
data,
lp = NULL,
par = NULL,
outcome.name = c("time", "status"),
remove = c("id", "num"),
model = NULL,
death.model = NULL,
death.lp = NULL,
death.par = NULL,
cens.model = NULL,
cens.lp = NULL,
cens.par = NULL,
...
)function (random generator)
data.frame (covariates)
linear predictor (formula or function)
optional list of model parameter
names of outcome (time and censoring status)
variables that will be removed from input data (if formula is not specified)
optional mets::phreg object
optional model for death (terminal) events
optional death linear predictor argument (formula or function)
optional list of death model parameters
optional model for censoring mechanism
optional censoring linear predictor argument (formula or function)
optional list of censoring model parameters
Additional arguments to outcome_lp